==> v11.1.2.zip: brewman/overlord/src/app/employee/employee-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { CostCentreListResolver } from '../cost-centre/cost-centre-list-resolver.service';

import { EmployeeDetailComponent } from './employee-detail/employee-detail.component';
import { EmployeeListComponent } from './employee-list/employee-list.component';
import { EmployeeListResolver } from './employee-list-resolver.service';
import { EmployeeResolver } from './employee-resolver.service';

const employeeRoutes: Routes = [
  {
    path: '',
    component: EmployeeListComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Employees',
    },
    resolve: {
      list: () => inject(EmployeeListResolver).resolve(),
    },
  },
  {
    path: 'new',
    component: EmployeeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Employees',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(EmployeeResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
  },
  {
    path: ':id',
    component: EmployeeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Employees',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(EmployeeResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(employeeRoutes)],
  exports: [RouterModule],
  providers: [EmployeeListResolver, EmployeeResolver],
})
export class EmployeeRoutingModule {}

==> v11.2.0.zip: brewman/overlord/src/app/employee/employee-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { CostCentreListResolver } from '../cost-centre/cost-centre-list-resolver.service';

import { EmployeeDetailComponent } from './employee-detail/employee-detail.component';
import { EmployeeListComponent } from './employee-list/employee-list.component';
import { EmployeeListResolver } from './employee-list-resolver.service';
import { EmployeeResolver } from './employee-resolver.service';

const employeeRoutes: Routes = [
  {
    path: '',
    component: EmployeeListComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Employees',
    },
    resolve: {
      list: () => inject(EmployeeListResolver).resolve(),
    },
  },
  {
    path: 'new',
    component: EmployeeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Employees',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(EmployeeResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
  },
  {
    path: ':id',
    component: EmployeeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Employees',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(EmployeeResolver).resolve(route),
      costCentres: () => inject(CostCentreListResolver).resolve(),
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(employeeRoutes)],
  exports: [RouterModule],
  providers: [EmployeeListResolver, EmployeeResolver],
})
export class EmployeeRoutingModule {}
